"""
NPR Convert - Nepal Rastra Bank Currency Converter
A command line tool to convert NPR to foreign currencies
using NRB's official exchange rates
"""

__version__ = "0.1.1"

from .converter import CurrencyConverter